@@ -766,6 +766,23 @@ def orient_propagation(dag):
     return dag
 
 
-# get the adjacent variables of a certain node in a graph
-def adjacent(graph, var):
+# get the parents of a node given a graph
+def parents(graph, var):
+    return graph[var]['par']
+
+
+# get the neighbours of a node given a graph
+def neighbours(graph, var):
     return graph[var]['par'] + graph[var]['nei'] + [v for v in graph if var in graph[v]['par']]
+
+
+# get the edges of a graph
+def edges(graph):
+    edge = pandas.DataFrame(columns=['from', 'to', 'type'])
+    for var in graph:
+        for par in parents(graph, var):
+            edge.loc[len(edge)] = [par, var, 'directed']
+        for nei in graph[var]['nei']:
+            if len(edge[edge['from'] == nei and edge['to'] == var]) == 0:
+                edge.loc[len(edge)] = [var, nei, 'undirected']
+    return edge
\ No newline at end of file
